"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueryModelPredicates = void 0;
const QueryPropertyPredicate_1 = require("./QueryPropertyPredicate");
const Where_1 = require("./Where");
class QueryModelPredicates {
    subOperations;
    constructor(pred) {
        this.subOperations = [];
        const keys = Object.keys(pred);
        keys.forEach((propertyKey) => {
            const propertyPredicates = (0, Where_1.getPropertyPredicates)(pred, propertyKey);
            if (typeof propertyPredicates !== 'object' || propertyPredicates instanceof Date || propertyPredicates instanceof Promise) {
                // shorthand form for 'eq' comparison
                this.subOperations.push(new QueryPropertyPredicate_1.QueryPropertyPredicate(propertyKey, 'eq', propertyPredicates));
            }
            else {
                const comparisonKeys = Object.keys(propertyPredicates);
                comparisonKeys.forEach((comparisonOp) => {
                    const comparison = (0, Where_1.getPropertyComparison)(propertyPredicates, comparisonOp);
                    this.subOperations.push(new QueryPropertyPredicate_1.QueryPropertyPredicate(propertyKey, comparisonOp, comparison));
                });
            }
        });
    }
    async toSql(metaModel, params, tablePrefix) {
        const parts = [];
        for (const predicate of this.subOperations) {
            const part = await predicate.toSql(metaModel, params, tablePrefix);
            /* istanbul ignore else */
            if (part.length) {
                parts.push(part);
            }
        }
        if (!parts.length) {
            return '';
        }
        return parts.join(' and ');
    }
}
exports.QueryModelPredicates = QueryModelPredicates;
//# sourceMappingURL=QueryModelPredicates.js.map